libbraiding: Computing with braids
==================================

Description
-----------

libbraiding is a library to compute several properties of braids,
including centralizer and conjugacy check.

License
-------

GPLv3+


Upstream Contact
----------------

Miguel Marco (mmarco@unizar.es)

https://github.com/miguelmarco/libbraiding
